@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: hotplug.c,v 3.12 2003/04/20 21:26:29 shuu Exp shuu $
+ *  $Id: hotplug.c,v 3.19 2003/09/14 05:49:37 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -24,16 +24,28 @@
 #define	DPRINT_ARGS(name,arg)
 #endif
 
+#define	AGENT_CMD(name)		{name, MU_MURASAKI "." name}
+#ifdef	INCLUDE_GENERIC_LIST
+#define	AGENT_GENERIC(name)	{name, MU_MURASAKI "." MU_ARG_GENERIC}
+#endif	/* INCLUDE_GENERIC_LIST */
+
 struct arg_command {
 	char *arg;
 	char *cmd;
 };
 
 struct arg_command cmd_table[] = {
-	{MU_ARG_USB,	MU_MURASAKI "." MU_ARG_USB},
-	{MU_ARG_PCI,	MU_MURASAKI "." MU_ARG_PCI},
-	{MU_ARG_NET,	MU_MURASAKI "." MU_ARG_NET},
-	{MU_ARG_IEEE1394,	MU_MURASAKI "." MU_ARG_IEEE1394},
+	AGENT_CMD(MU_ARG_USB),
+	AGENT_CMD(MU_ARG_PCI),
+	AGENT_CMD(MU_ARG_IEEE1394),
+#ifdef	INCLUDE_GENERIC_LIST
+	AGENT_GENERIC(MU_ARG_NET),
+	AGENT_GENERIC(MU_ARG_SCSI),
+	AGENT_GENERIC(MU_ARG_SCSI_HOST),
+	AGENT_GENERIC(MU_ARG_SCSI_DEVICE),
+	AGENT_GENERIC(MU_ARG_BLOCK),
+	AGENT_GENERIC(MU_ARG_USB_HOST),
+#endif	/* INCLUDE_GENERIC_LIST */
 	{NULL,NULL}
 };
 
@@ -111,57 +123,53 @@ main(int argc,char **argv,char **env)
 	DPRINT_ARGS("argv",argv);
 
 	/* check device */
-	switch(check_config(argv[1]))  {
-	case INVALID:
-		exit(1);
-		break;	/* for warning */
-	case ARG_OFF:
+	if (check_config(argv[1]) == ARG_OFF) {
 		syslog(LOG_LEVEL,"%s is defined as \"%s\"",
 			config_list[0],config_list[1]);
 		exit(0);
-		break;
-	case ARG_ON:	/* do nothing */
-		break;
 	}
 
 	cmd[1] = NULL;
+	cmd[2] = NULL;
 	for (idx = 0;cmd_table[idx].arg != NULL;idx++) {
 		if (strcmp(argv[1],cmd_table[idx].arg) == 0) {
 			cmd[0] = cmd_table[idx].cmd;
-#ifdef	DEBUG
-			switch(idx) {
-			case 0:	/* USB */
-				DPRINTF(LOG_LEVEL,"%s ACTION=%s PRODUCT=%s TYPE=%s INTERFACE=%s DEVFS=%s DEVICE=%s",
-					argv[1],getenv("ACTION"),getenv("PRODUCT"),
-					getenv("TYPE"),getenv("INTERFACE"),getenv("DEVFS"),
-					getenv("DEVICE"));
-					break;
-			case 1:	/* PCI */
-				DPRINTF(LOG_LEVEL,"%s ACTION=%s PCI_CLASS=%s PCI_ID=%s PCI_SUBSYS_ID=%s PCI_SLOT_NAME=%s",
-					argv[1],getenv("ACTION"),getenv("PCI_CLASS"),
-					getenv("PCI_ID"),getenv("PCI_SUBSYS_ID"),
-					getenv("PCI_SLOT_NAME"));
-					break;
-			case 2:	/* NET */
-				DPRINTF(LOG_LEVEL,"%s ACTION=%s INTERFACE=%s",
-					argv[1],getenv("ACTION"),getenv("INTERFACE"));
-					break;
-			case 3:	/* IEEE1394 */
-				DPRINTF(LOG_LEVEL,"%s ACTION=%s VENDOR_ID=%s GUID=%s SPECIFIER_ID=%s VERSION=%s",
-					argv[1],getenv("ACTION"),getenv("VENDOR_ID"),
-					getenv("GUID"),getenv("SPECIFIER_ID"),getenv("VERSION"));
-			}
-#endif
+#ifdef	INCLUDE_GENERIC_LIST
+			/* When cmd == "generic", 
+			 *  call the agent with the real device.
+			 */
+			if (strcmp(cmd[0],MU_MURASAKI "." MU_ARG_GENERIC) == 0)
+				cmd[1] = argv[1];
+#endif	/* INCLUDE_GENERIC_LIST */
 			break;
 		}
 	}
 	if (cmd_table[idx].arg == NULL) {
-		syslog(LOG_LEVEL,"unknown argument \"%s\"",argv[1]);
-#ifdef	DEBUG
-		print_args("argv",argv);
-		print_args("env",env);
+		if (access(GENERICLIST_PATH,R_OK) == 0) {
+			char *list[LIST_MAX];
+			int i;
+
+			list_from_file(GENERICLIST_PATH,list,LIST_MAX);
+			for (i = 0;list[i] != NULL;i++) {
+				if (strcmp(argv[1],list[i]) == 0) {
+					cmd[0] = MU_MURASAKI "." MU_ARG_GENERIC;
+					cmd[1] = argv[1];
+				}
+			}
+#ifdef	KERNEL_JOB
+			if (list[0] != NULL)
+				free(list[0]);
 #endif
-		exit(1);
+		}
+		if (cmd[1] == NULL) {
+			syslog(LOG_LEVEL,"Unknown Hotplug name \"%s\"",argv[1]);
+			syslog(LOG_LEVEL,"Add \"%s\" into murasaki.genericlist if you want",argv[1]);
+#ifdef	DEBUG
+			print_args("argv",argv);
+			print_args("env",env);
+#endif
+			exit(1);
+		}
 	}
 	closelog();
 	DPRINT_ARGS("cmd",cmd);
