@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: id.c,v 1.2 2002/03/04 04:23:54 shuu Exp shuu $
+ *  $Id: id.c,v 1.3 2003/05/17 20:37:07 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -12,9 +12,12 @@
 #include	"murasaki_ieee1394.h"
 
 int
-get_id_ieee1394(MU_ieee1394_config_t *config)
+get_id_ieee1394(struct mu_op *opp)
 {
 	char *ptr;
+	MU_ieee1394_config_t *config;
+
+	config = (MU_ieee1394_config_t *)opp->config;
 
 	ptr = getenv("VENDOR_ID");
 	config->vendor = strtoul(ptr,NULL,16);
