@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *	$Id: murasaki_ieee1394.h,v 1.1 2001/10/29 16:55:44 shuu Exp $
+ *	$Id: murasaki_ieee1394.h,v 1.3 2003/05/17 20:42:40 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -14,6 +14,18 @@
 #define	IEEE1394_MATCH_SPECIFIER_ID	0x0004
 #define	IEEE1394_MATCH_VERSION		0x0008
 
+typedef struct {
+	char *name;
+	unsigned int match_flags;
+	unsigned int vendor;
+	unsigned int model;
+/* Now, 'guid' is not available 
+	long long unsigned guid;
+*/
+	unsigned int specifier;
+	unsigned int version;
+} MU_ieee1394_config_t;
+
+extern int get_id_ieee1394(struct mu_op *);
+
 #endif	/* _MURASAKI_IEEE1394_H */
-
-
