@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: beep.c,v 3.1 2001/10/29 17:13:03 shuu Exp shuu $
+ *  $Id: beep.c,v 3.4 2003/05/17 20:53:41 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  *  beep function is based on beep() in cardmgr.c(pcmcia-cs)
@@ -12,8 +12,10 @@
 #include	<fcntl.h>
 #include	<unistd.h>
 #include	<sys/ioctl.h>
+#include	<stdlib.h>		/* for getenv */
+#include	<string.h>		/* for strcmp */
 
-#include	"env.h"
+#include	"murasaki.h"
 
 #define	SLEEP_TIME	100
 #define	BEEP_TIME	100
@@ -22,10 +24,18 @@
 #define	BEEP_ERROR_STEP	1200
 
 void
-beep(int status)
+beep(int status,int flag)
 {
 	int fd;
 	static unsigned int freq = BEEP_BASE;
+	char *beep;
+
+	if ((beep = getenv("MURASAKI_BEEP")) != NULL) {
+		if (strcmp(beep,"off") == 0) 
+			return;
+	} else if (!FLAG_CHECK(flag,FLAG_BEEP)) {
+		return;
+	}
 
 	if (status == GOOD)
 		freq -= BEEP_GOOD_STEP;
