@@ -1,14 +1,26 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: list.c,v 3.1 2001/10/29 17:17:07 shuu Exp shuu $
+ *  $Id: list.c,v 3.5 2003/08/10 04:08:09 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
 #include	<stdio.h>
+#include	<string.h>
 
 #include	"murasaki.h"
-#include	"env.h"
+
+int
+find_module_list(char **list, char *name)
+{
+	int i;
+
+	for(i = 0;list[i] != NULL;i++) {
+		if (strcmp(list[i],name) == 0)
+			return FOUND;
+	}
+	return NOT_FOUND;
+}
 
 /*
  * list[0] -> something ... list[i] -> ptr , list[i+1] -> NULL
@@ -18,8 +30,11 @@ add_to_list(char **list,char *ptr,int listmax)
 {
 	int i;
 
-	for(i = 0;i < listmax - 1 && list[i] != NULL;i++)
-		;		
+	/* skip to end */
+	for(i = 0;i < listmax - 1 && list[i] != NULL;i++) {
+		if (strcmp(list[i],ptr) == 0)
+			return GOOD;	/* same one */
+	}
 	if (i == listmax - 1)
 		return INVALID;
 	list[i] = ptr;
@@ -38,6 +53,10 @@ count_of_list(char **list)
 	return i;
 }
 
+/*
+ * This function does NOT focus on speed.
+ * The order of modules is important.
+ */
 void
 remove_from_list(char **list,int idx)
 {
@@ -52,6 +71,7 @@ remove_from_list(char **list,int idx)
 	list[i-1] = NULL;
 }
 
+#ifdef	DEBUG
 void
 print_list(char **list)
 {
@@ -60,3 +80,4 @@ print_list(char **list)
 	for(i = 0;list[i] != NULL;i++)
 		DPRINTF(LOG_LEVEL,"list[%d]=\"%s\"",i,list[i]);
 }
+#endif	/* DEBUG */
