@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: class.c,v 3.2 2001/10/29 17:34:29 shuu Exp shuu $
+ *  $Id: class.c,v 1.2 2003/05/17 21:01:51 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -9,15 +9,18 @@
 #include	<stdlib.h>
 
 #include	"murasaki.h"
-#include	"env.h"
+#include	"murasaki_pci.h"
 
 /*
  * format: x
  */
 int
-get_id_pci_class(MU_pci_config_t *config)
+get_id_pci_class(struct mu_op *opp)
 {
 	char *ptr;
+	MU_pci_config_t *config;
+
+	config = (MU_pci_config_t *)opp->config;
 
 	ptr = getenv("PCI_CLASS");
 	if (ptr == NULL)
