@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: id.c,v 3.3 2001/10/29 17:35:38 shuu Exp shuu $
+ *  $Id: id.c,v 1.2 2003/05/17 21:01:30 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -9,7 +9,7 @@
 #include	<stdlib.h>
 
 #include	"murasaki.h"
-#include	"env.h"
+#include	"murasaki_pci.h"
 
 #define		SEP	':'	/* changed 2.4.0-test12-pre8 */
 
@@ -35,10 +35,13 @@ get_id_sub(MU_pci_id_t *id,char *ptr)
 }
 
 int
-get_id_pci_id(MU_pci_config_t *config)
+get_id_pci_id(struct mu_op *opp)
 {
 	char *ptr;
 	MU_pci_id_t id;
+	MU_pci_config_t *config;
+
+	config = (MU_pci_config_t *)opp->config;
 
 	ptr = getenv("PCI_ID");
 	if (ptr == NULL)
