@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: product.c,v 3.4 2001/10/29 17:41:16 shuu Exp shuu $
+ *  $Id: product.c,v 3.6 2003/05/17 21:06:01 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -9,7 +9,7 @@
 #include	<stdlib.h>
 
 #include	"murasaki.h"
-#include	"env.h"
+#include	"murasaki_usb.h"
 
 #define		SEP	'/'
 
@@ -18,10 +18,13 @@
  */
 
 int
-get_id_usb_product(MU_usb_config_t *config)
+get_id_usb_product(struct mu_op *opp)
 {
 	char *ptr;
 	char *sep;
+	MU_usb_config_t *config;
+
+	config = (MU_usb_config_t *)opp->config;
 
 	ptr = getenv("PRODUCT");
 	if (ptr == NULL) {
