@@ -1,7 +1,7 @@
 /*
  *  Copyright (c) by Shuu Yamaguchi <shuu@dotaster.com>
  *
- *  $Id: type.c,v 3.2 2001/10/29 17:43:36 shuu Exp shuu $
+ *  $Id: type.c,v 3.5 2003/06/08 20:21:03 shuu Exp shuu $
  *
  *  Can be freely distributed and used under the terms of the GNU GPL.
  */
@@ -9,7 +9,7 @@
 #include	<stdlib.h>
 
 #include	"murasaki.h"
-#include	"env.h"
+#include	"murasaki_usb.h"
 
 #define		SEP	'/'
 
@@ -41,25 +41,28 @@ get_type_sub(MU_usb_type_t *tp,char *ptr)
 }
 
 int
-get_id_usb_type(MU_usb_config_t *config)
+get_id_usb_type(struct mu_op *opp)
 {
 	char *ptr;
 	MU_usb_type_t face;
+	MU_usb_config_t *config;
+
+	config = (MU_usb_config_t *)opp->config;
 
 	ptr = getenv("TYPE");
-	if (ptr == NULL)
-		return INVALID;
-	if (get_type_sub (&face, ptr) == INVALID)
-		return INVALID;
-	config->device = face;
+	if (ptr != NULL) {
+		if (get_type_sub (&face, ptr) == INVALID)
+			return INVALID;
+		config->device = face;
+	}
 
 	if (config->device.class == 0) {
 		ptr = getenv("INTERFACE");
-		if (ptr == NULL)
-			return INVALID;
-		if (get_type_sub(&face, ptr) == INVALID)
-			return INVALID;
-		config->interface = face;
+		if (ptr != NULL) {
+			if (get_type_sub(&face, ptr) == INVALID)
+				return INVALID;
+			config->interface = face;
+		}
 	} else {
 		config->interface.class = 0;
 		config->interface.subclass = 0;
